@@ -1,16 +1,17 @@
 import numpy as np
 import tensorflow as tf
 from tensorflow.keras import Model, Input
-from tensorflow.keras.layers import Dropout, Softmax
+from tensorflow.keras.layers import Dropout
 from tensorflow.keras.optimizers import Adam
 from tensorflow.keras import regularizers
+from tensorflow.keras.losses import SparseCategoricalCrossentropy
 
 from graphgallery.nn.layers import MeanAggregator, GCNAggregator
 from graphgallery.nn.models import SemiSupervisedModel
 from graphgallery.sequence import SAGEMiniBatchSequence
 from graphgallery.utils.graph_utils import construct_neighbors
 from graphgallery.utils.shape_utils import set_equal_in_length
-from graphgallery import astensor, asintarr, normalize_x, Bunch
+from graphgallery import astensors, asintarr, normalize_x, Bunch
 
 
 class GraphSAGE(SemiSupervisedModel):
@@ -38,7 +39,7 @@ class GraphSAGE(SemiSupervisedModel):
                 `5` sencond-order neighbors, and the radius for `GraphSAGE` is `2`)
             norm_x (String, optional): 
                 How to normalize the node feature matrix. See `graphgallery.normalize_x`
-                (default :str: `l1`)
+                (default :obj: `None`)
             device (String, optional): 
                 The device where the model is running on. You can specified `CPU` or `GPU` 
                 for the model. (default: :str: `CPU:0`, i.e., running on the 0-th `CPU`)
@@ -52,7 +53,7 @@ class GraphSAGE(SemiSupervisedModel):
 
     """
 
-    def __init__(self, adj, x, labels, n_samples=[15, 5], norm_x='l1',
+    def __init__(self, adj, x, labels, n_samples=[15, 5], norm_x=None,
                  device='CPU:0', seed=None, name=None, **kwargs):
 
         super().__init__(adj, x, labels, device=device, seed=seed, name=name, **kwargs)
@@ -63,8 +64,7 @@ class GraphSAGE(SemiSupervisedModel):
 
     def preprocess(self, adj, x):
         super().preprocess(adj, x)
-        # check the input adj and x, and convert them into proper data types
-        adj, x = self._check_inputs(adj, x)
+        adj, x = self.adj, self.x
 
         if self.norm_x:
             x = normalize_x(x, norm=self.norm_x)
@@ -75,11 +75,12 @@ class GraphSAGE(SemiSupervisedModel):
         x = np.vstack([x, np.zeros(self.n_features, dtype=self.floatx)])
 
         with tf.device(self.device):
-            self.x_norm, self.neighbors = astensor(x), neighbors
+            self.x_norm, self.neighbors = astensors(x), neighbors
 
     def build(self, hiddens=[32], activations=['relu'], dropouts=[0.5], l2_norms=[5e-4], lr=0.01,
-              output_normalize=False, aggrator='mean'):
+              use_bias=True, output_normalize=False, aggrator='mean'):
 
+        ############# Record paras ###########
         local_paras = locals()
         local_paras.pop('self')
         paras = Bunch(**local_paras)
@@ -90,6 +91,7 @@ class GraphSAGE(SemiSupervisedModel):
         # update all parameters
         self.paras.update(paras)
         self.model_paras.update(paras)
+        ######################################
 
         with tf.device(self.device):
 
@@ -108,10 +110,10 @@ class GraphSAGE(SemiSupervisedModel):
             aggrators = []
             for i, (hid, activation, l2_norm) in enumerate(zip(hiddens, activations, l2_norms)):
                 # you can use `GCNAggregator` instead
-                aggrators.append(Agg(hid, concat=True, activation=activation,
+                aggrators.append(Agg(hid, concat=True, activation=activation, use_bias=use_bias,
                                      kernel_regularizer=regularizers.l2(l2_norm)))
 
-            aggrators.append(Agg(self.n_classes))
+            aggrators.append(Agg(self.n_classes, use_bias=use_bias))
 
             h = [tf.nn.embedding_lookup(x, node) for node in [nodes, *neighbors]]
             for agg_i, aggrator in enumerate(aggrators):
@@ -126,10 +128,10 @@ class GraphSAGE(SemiSupervisedModel):
             h = h[0]
             if output_normalize:
                 h = tf.nn.l2_normalize(h, axis=1)
-            output = Softmax()(h)
 
-            model = Model(inputs=[x, nodes, *neighbors], outputs=output)
-            model.compile(loss='sparse_categorical_crossentropy', optimizer=Adam(lr=lr), metrics=['accuracy'])
+            model = Model(inputs=[x, nodes, *neighbors], outputs=h)
+            model.compile(loss=SparseCategoricalCrossentropy(from_logits=True),
+                          optimizer=Adam(lr=lr), metrics=['accuracy'])
 
             self.model = model
 
