@@ -2,16 +2,17 @@ import numpy as np
 import scipy.sparse as sp
 import tensorflow as tf
 from tensorflow.keras import Model, Input
-from tensorflow.keras.layers import Dropout, Softmax, Concatenate, BatchNormalization
+from tensorflow.keras.layers import Dropout, Concatenate, BatchNormalization
 from tensorflow.keras.optimizers import Nadam
 from tensorflow.keras import regularizers
+from tensorflow.keras.losses import SparseCategoricalCrossentropy
 
 from graphgallery.nn.layers import Top_k_features, LGConvolution, DenseGraphConv
 from graphgallery.nn.models import SemiSupervisedModel
 from graphgallery.sequence import FullBatchNodeSequence
 from graphgallery.utils.shape_utils import set_equal_in_length, get_length
 from graphgallery.utils.graph_utils import get_indice_graph
-from graphgallery import astensor, asintarr, sample_mask, normalize_x, normalize_adj, Bunch, repeat
+from graphgallery import astensors, asintarr, sample_mask, normalize_x, normalize_adj, Bunch, repeat
 
 
 class LGCN(SemiSupervisedModel):
@@ -36,7 +37,7 @@ class LGCN(SemiSupervisedModel):
                 i.e., math:: \hat{A} = D^{-\frac{1}{2}} A D^{-\frac{1}{2}})
             norm_x (String, optional):
                 How to normalize the node feature matrix. See `graphgallery.normalize_x`
-                (default :str: `l1`)
+                (default :obj: `None`)
             device (String, optional):
                 The device where the model is running on. You can specified `CPU` or `GPU`
                 for the model. (default: :str: `CPU:0`, i.e., running on the 0-th `CPU`)
@@ -50,7 +51,7 @@ class LGCN(SemiSupervisedModel):
 
     """
 
-    def __init__(self, adj, x, labels, norm_adj=-0.5, norm_x='l1',
+    def __init__(self, adj, x, labels, norm_adj=-0.5, norm_x=None,
                  device='CPU:0', seed=None, name=None, **kwargs):
 
         super().__init__(adj, x, labels, device=device, seed=seed, name=name, **kwargs)
@@ -63,15 +64,13 @@ class LGCN(SemiSupervisedModel):
 
     def preprocess(self, adj, x):
         super().preprocess(adj, x)
-        # check the input adj and x, and convert them into proper data types
-        adj, x = self._check_inputs(adj, x)
+        adj, x = self.adj, self.x
 
         if self.norm_adj:
             adj = normalize_adj(adj, self.norm_adj)
 
-        # TODO: the input adj can be dense matrix
-#         if sp.isspmatrix(adj):
-#             adj = adj.toarray()
+        if sp.isspmatrix(adj):
+            adj = adj.toarray()
 
         if self.norm_x:
             x = normalize_x(x, norm=self.norm_x)
@@ -81,6 +80,7 @@ class LGCN(SemiSupervisedModel):
     def build(self, hiddens=[32], n_filters=[8, 8], activations=[None], dropouts=[0.8], l2_norms=[5e-4],
               lr=0.1, use_bias=False, k=8):
 
+        ############# Record paras ###########
         local_paras = locals()
         local_paras.pop('self')
         paras = Bunch(**local_paras)
@@ -95,6 +95,7 @@ class LGCN(SemiSupervisedModel):
         # update all parameters
         self.paras.update(paras)
         self.model_paras.update(paras)
+        ######################################
 
         with tf.device(self.device):
 
@@ -121,10 +122,10 @@ class LGCN(SemiSupervisedModel):
                                kernel_regularizer=regularizers.l2(l2_norms[-1]))([h, adj])
 
             h = tf.boolean_mask(h, mask)
-            output = Softmax()(h)
 
-            model = Model(inputs=[x, adj, mask], outputs=output)
-            model.compile(loss='sparse_categorical_crossentropy', optimizer=Nadam(lr=lr), metrics=['accuracy'])
+            model = Model(inputs=[x, adj, mask], outputs=h)
+            model.compile(loss=SparseCategoricalCrossentropy(from_logits=True),
+                          optimizer=Nadam(lr=lr), metrics=['accuracy'])
 
             self.k = k
             self.model = model
@@ -135,7 +136,8 @@ class LGCN(SemiSupervisedModel):
         index = get_indice_graph(self.adj_norm, index, batch_size)
         while index.size < self.k:
             index = get_indice_graph(self.adj_norm, index)
-        adj = self.adj_norm[index][:, index].toarray()
+            
+        adj = self.adj_norm[index][:, index]
         x = self.x_norm[index]
         mask = mask[index]
         labels = self.labels[index[mask]]
@@ -149,14 +151,15 @@ class LGCN(SemiSupervisedModel):
         index = asintarr(index)
         mask = sample_mask(index, self.n_nodes)
         index = get_indice_graph(self.adj_norm, index)
+        
         while index.size < self.k:
             index = get_indice_graph(self.adj_norm, index)
-        adj = self.adj_norm[index][:, index].toarray()
+        adj = self.adj_norm[index][:, index]
         x = self.x_norm[index]
         mask = mask[index]
 
         with tf.device(self.device):
-            x, adj, mask = astensor([x, adj, mask])
+            x, adj, mask = astensors([x, adj, mask])
             logit = self.model.predict_on_batch([x, adj, mask])
 
         if tf.is_tensor(logit):
