@@ -1,5 +1,5 @@
 import os
-import datetime
+import warnings
 import numpy as np
 import tensorflow as tf
 import scipy.sparse as sp
@@ -12,7 +12,14 @@ from tensorflow.keras.callbacks import EarlyStopping, ModelCheckpoint
 from graphgallery.nn.models import BaseModel
 from graphgallery.utils.history import History
 from graphgallery.utils.tqdm import tqdm
-from graphgallery import asintarr, astensor, Bunch
+from graphgallery import asintarr, Bunch
+
+# Ignora warnings:
+#     UserWarning: Converting sparse IndexedSlices to a dense Tensor of unknown shape. This may consume a large amount of memory.
+#     This is caused by `tf.gather` and it will be solved in future tensorflow version.
+
+warnings.filterwarnings(
+    'ignore', '.*Converting sparse IndexedSlices to a dense Tensor of unknown shape.*')
 
 
 class SemiSupervisedModel(BaseModel):
@@ -44,6 +51,29 @@ class SemiSupervisedModel(BaseModel):
     def __init__(self, adj, x, labels=None, device='CPU:0', seed=None, name=None, **kwargs):
         super().__init__(adj, x, labels, device, seed, name, **kwargs)
 
+    def preprocess(self, adj, x):
+        """Preprocess the input adjacency matrix and feature matrix, e.g., normalization.
+        And convert them to tf.tensor. 
+
+        Arguments:
+        ----------
+            adj: shape (N, N), `scipy.sparse.csr_matrix` (or `csc_matrix`) if 
+                `is_adj_sparse=True`, Numpy array-like if `is_adj_sparse=False`.
+                The input `symmetric` adjacency matrix, where `N` is the number 
+                of nodes in graph.
+            x: shape (N, F), `scipy.sparse.csr_matrix` (or `csc_matrix`) if 
+                `is_x_sparse=True`, Numpy array-like if `is_x_sparse=False`.
+                The input node feature matrix, where `F` is the dimension of node features.
+
+        Note:
+        ----------
+            By default, `adj` is sparse matrix and `x` is dense array. Both of them are 
+            2-D matrices.
+        """
+        # check the input adj and x, and convert them to appropriate forms
+        self.adj, self.x = self._check_inputs(adj, x)
+        self.n_nodes, self.n_features = x.shape
+
     def build(self):
         """
             Build the model using customized hyperparameters.
@@ -127,21 +157,24 @@ class SemiSupervisedModel(BaseModel):
 
         # TODO use tensorflow callbacks
 
+        ############# Record paras ###########
         local_paras = locals()
         local_paras.pop('self')
         local_paras.pop('idx_train')
         local_paras.pop('idx_val')
         paras = Bunch(**local_paras)
+        ######################################
 
         # Check if model has been built
-        if not self.model:
+        if self.model is None:
             raise RuntimeError('You must compile your model before training/testing/predicting. Use `model.build()`.')
 
         if isinstance(idx_train, Sequence):
             train_data = idx_train
         else:
+            idx_train = asintarr(idx_train)
             train_data = self.train_sequence(idx_train)
-            self.idx_train = asintarr(idx_train)
+            self.idx_train = idx_train
 
         validation = idx_val
 
@@ -149,8 +182,9 @@ class SemiSupervisedModel(BaseModel):
             if isinstance(idx_val, Sequence):
                 val_data = idx_val
             else:
+                idx_val = asintarr(idx_val)
                 val_data = self.test_sequence(idx_val)
-                self.idx_val = asintarr(idx_val)
+                self.idx_val = idx_val
 
         history = History(monitor_metric=monitor,
                           early_stop_metric=early_stop_metric)
@@ -160,10 +194,12 @@ class SemiSupervisedModel(BaseModel):
         if not weight_path.endswith('.h5'):
             weight_path += '.h5'
 
+        ############# Record paras ###########
         paras.update(Bunch(weight_path=weight_path))
         # update all parameters
         self.paras.update(paras)
         self.train_paras.update(paras)
+        ######################################
 
         if validation is None:
             history.register_monitor_metric('acc')
@@ -272,24 +308,27 @@ class SemiSupervisedModel(BaseModel):
             and validation metrics values (if applicable).
 
         """
+        ############# Record paras ###########
         local_paras = locals()
         local_paras.pop('self')
         local_paras.pop('idx_train')
         local_paras.pop('idx_val')
         paras = Bunch(**local_paras)
+        ######################################
 
         if not tf.__version__ >= '2.2.0':
             raise RuntimeError(f'This method is only work for tensorflow version >= 2.2.0.')
 
         # Check if model has been built
-        if not self.model:
+        if self.model is None:
             raise RuntimeError('You must compile your model before training/testing/predicting. Use `model.build()`.')
 
         if isinstance(idx_train, Sequence):
             train_data = idx_train
         else:
+            idx_train = asintarr(idx_train)
             train_data = self.train_sequence(idx_train)
-            self.idx_train = asintarr(idx_train)
+            self.idx_train = idx_train
 
         validation = idx_val
 
@@ -297,8 +336,9 @@ class SemiSupervisedModel(BaseModel):
             if isinstance(idx_val, Sequence):
                 val_data = idx_val
             else:
+                idx_val = asintarr(idx_val)
                 val_data = self.test_sequence(idx_val)
-                self.idx_val = asintarr(idx_val)
+                self.idx_val = idx_val
 
         model = self.model
         if not isinstance(callbacks, callbacks_module.CallbackList):
@@ -325,14 +365,16 @@ class SemiSupervisedModel(BaseModel):
                                           monitor=monitor,
                                           save_best_only=True,
                                           save_weights_only=not as_model,
-                                          verbose=verbose)
+                                          verbose=0)
             callbacks.append(mc_callback)
         callbacks.set_model(model)
 
+        ############# Record paras ###########
         paras.update(Bunch(weight_path=weight_path))
         # update all parameters
         self.paras.update(paras)
         self.train_paras.update(paras)
+        ######################################
 
         # leave it blank for the future
         allowed_kwargs = set([])
@@ -372,7 +414,7 @@ class SemiSupervisedModel(BaseModel):
 
         if save_best:
             self.load(weight_path, as_model=as_model)
-            if os.exist(weight_path):
+            if os.path.exists(weight_path):
                 os.remove(weight_path)
 
         return model.history
@@ -409,8 +451,9 @@ class SemiSupervisedModel(BaseModel):
         if isinstance(index, Sequence):
             test_data = index
         else:
+            index = asintarr(index)
             test_data = self.test_sequence(index)
-            self.idx_test = asintarr(index)
+            self.idx_test = index
 
         if self.do_before_test:
             self.do_before_test(**kwargs)
@@ -531,32 +574,12 @@ class SemiSupervisedModel(BaseModel):
         return self.train_sequence(index)
 
     def _test_predict(self, index):
-        """
-            Predict the output accuracy for the `index` of nodes.
-
-        Note:
-        ----------
-            You must compile your model before training/testing/predicting. 
-            Use `model.build()`.
-
-        Arguments:
-        ----------
-            index: Numpy array-like, `list` or integer scalar
-                The index of nodes that will be computed.    
-
-        Return:
-        ----------
-            accuracy: Float scalar
-                The output accuracy of the `index` of nodes.
-
-        """
         index = asintarr(index)
         logit = self.predict(index)
         predict_class = logit.argmax(1)
         labels = self.labels[index]
         return (predict_class == labels).mean()
-        
-#     @tf.function
+
     def __call__(self, inputs):
         return self.model(inputs)
 
@@ -565,21 +588,43 @@ class SemiSupervisedModel(BaseModel):
         """Return the weights of model, type `tf.Tensor`."""
         return self.model.weights
 
-    @property
-    def np_weights(self):
+    def get_weights(self):
         """Return the weights of model, type Numpy array-like."""
-        return [weight.numpy() for weight in self.weights]
+        return self.model.get_weights()
 
     @property
     def trainable_variables(self):
         """Return the trainable weights of model, type `tf.Tensor`."""
         return self.model.trainable_variables
 
+    def reset_weights(self):
+        """reset the model to the first time.
+        """
+        model = self.model
+        if self.backup is None:
+            raise RuntimeError("You must store the `backup` before `reset_weights`."
+                               "`backup` will be automatically stored when the model is built.")
+        for w, wb in zip(model.weights, self.backup):
+            w.assign(wb)
+
+    def reset_optimizer(self):
+
+        model = self.model
+        if hasattr(model, 'optimizer'):
+            for var in model.optimizer.variables():
+                var.assign(tf.zeros_like(var))
+
+    def reset_lr(self, value):
+        model = self.model
+        if not hasattr(model, 'optimizer'):
+            raise RuntimeError("The model has not attribute `optimizer`!")
+        model.optimizer.learning_rate.assign(value)
+
     @property
     def close(self):
         """Close the session of model and set `built` to False."""
         self.model = None
         K.clear_session()
-        
+
     def __repr__(self):
         return 'Semi-Supervised model: ' + self.name + ' in ' + self.device
