@@ -3,12 +3,13 @@ from tensorflow.keras import Model, Input
 from tensorflow.keras.layers import Dense
 from tensorflow.keras.optimizers import Adam
 from tensorflow.keras import regularizers
+from tensorflow.keras.losses import SparseCategoricalCrossentropy
 
 from graphgallery.nn.layers import SGConvolution
 from graphgallery.nn.models import SemiSupervisedModel
 from graphgallery.sequence import FullBatchNodeSequence
 from graphgallery.utils.shape_utils import repeat
-from graphgallery import astensor, asintarr, normalize_x, normalize_adj, Bunch
+from graphgallery import astensors, asintarr, normalize_x, normalize_adj, Bunch
 
 
 class SGC(SemiSupervisedModel):
@@ -35,7 +36,7 @@ class SGC(SemiSupervisedModel):
                 i.e., math:: \hat{A} = D^{-\frac{1}{2}} A D^{-\frac{1}{2}}) 
             norm_x (String, optional): 
                 How to normalize the node feature matrix. See `graphgallery.normalize_x`
-                (default :str: `l1`)
+                (default :obj: `None`)
             device (String, optional): 
                 The device where the model is running on. You can specified `CPU` or `GPU` 
                 for the model. (default: :str: `CPU:0`, i.e., running on the 0-th `CPU`)
@@ -49,7 +50,7 @@ class SGC(SemiSupervisedModel):
     """
 
     def __init__(self, adj, x, labels, order=2,
-                 norm_adj=-0.5, norm_x='l1',
+                 norm_adj=-0.5, norm_x=None,
                  device='CPU:0', seed=None, name=None, **kwargs):
 
         super().__init__(adj, x, labels, device=device, seed=seed, name=name, **kwargs)
@@ -61,8 +62,7 @@ class SGC(SemiSupervisedModel):
 
     def preprocess(self, adj, x):
         super().preprocess(adj, x)
-        # check the input adj and x, and convert them into proper data types
-        adj, x = self._check_inputs(adj, x)
+        adj, x = self.adj, self.x
 
         if self.norm_adj:
             adj = normalize_adj(adj, self.norm_adj)
@@ -71,11 +71,12 @@ class SGC(SemiSupervisedModel):
             x = normalize_x(x, norm=self.norm_x)
 
         with tf.device(self.device):
-            x, adj = astensor([x, adj])
+            x, adj = astensors([x, adj])
             x = SGConvolution(order=self.order)([x, adj])
             self.x_norm, self.adj_norm = x, adj
 
-    def build(self, lr=0.2, l2_norms=5e-5):
+    def build(self, lr=0.2, l2_norms=[5e-5], use_bias=True):
+        ############# Record paras ###########
         l2_norms = repeat(l2_norms, 1)
         local_paras = locals()
         local_paras.pop('self')
@@ -83,15 +84,17 @@ class SGC(SemiSupervisedModel):
         # update all parameters
         self.paras.update(paras)
         self.model_paras.update(paras)
+        ######################################
 
         with tf.device(self.device):
 
             x = Input(batch_shape=[None, self.n_features], dtype=self.floatx, name='features')
 
-            output = Dense(self.n_classes, activation='softmax', kernel_regularizer=regularizers.l2(l2_norms[0]))(x)
+            output = Dense(self.n_classes, activation=None, use_bias=use_bias, kernel_regularizer=regularizers.l2(l2_norms[0]))(x)
 
             model = Model(inputs=x, outputs=output)
-            model.compile(loss='sparse_categorical_crossentropy', optimizer=Adam(lr=lr), metrics=['accuracy'])
+            model.compile(loss=SparseCategoricalCrossentropy(from_logits=True),
+                          optimizer=Adam(lr=lr), metrics=['accuracy'])
 
             self.model = model
 
