@@ -4,7 +4,7 @@ from numbers import Number
 
 def repeat(src, length):
     if src is None:
-        return src
+        return [None for _ in range(length)]
     if isinstance(src, (Number, str)):
         return list(itertools.repeat(src, length))
     if (len(src) > length):
